# Welcome to prismatools


[![image](https://img.shields.io/pypi/v/prismatools.svg)](https://pypi.python.org/pypi/prismatools)
[![image](https://img.shields.io/conda/vn/conda-forge/prismatools.svg)](https://anaconda.org/conda-forge/prismatools)

[![logo](https://raw.githubusercontent.com/gthlor/prismatools/main/docs/assets/logo150_nobg.png)](https://github.com/gthlor/prismatools/blob/main/docs/assets/logo150_nobg.png)


**prismatools** is an open-source Python package for reading, analyzing, and visualizing hyperspectral imagery from the PRISMA mission.


-   Free software: MIT License
-   Documentation: https://gthlor.github.io/prismatools


## Features

-   TODO
